<?php if (isset($component)) { $__componentOriginal166a02a7c5ef5a9331faf66fa665c256 = $component; } ?>
<?php if (isset($attributes)) { $__attributesOriginal166a02a7c5ef5a9331faf66fa665c256 = $attributes; } ?>
<?php $component = Illuminate\View\AnonymousComponent::resolve(['view' => 'filament-panels::components.page.index','data' => []] + (isset($attributes) && $attributes instanceof Illuminate\View\ComponentAttributeBag ? $attributes->all() : [])); ?>
<?php $component->withName('filament-panels::page'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php if (isset($attributes) && $attributes instanceof Illuminate\View\ComponentAttributeBag): ?>
<?php $attributes = $attributes->except(\Illuminate\View\AnonymousComponent::ignoredParameterNames()); ?>
<?php endif; ?>
<?php $component->withAttributes([]); ?>

    
    <div class="flex flex-wrap items-end gap-3 mb-6">

        
        <div class="flex gap-1">
            <?php if(\Livewire\Mechanisms\ExtendBlade\ExtendBlade::isRenderingLivewireComponent()): ?><!--[if BLOCK]><![endif]--><?php endif; ?><?php $__currentLoopData = ['month' => 'Este mes', 'lastmonth' => 'Mes pasado', 'months3' => 'Últ. 3 meses']; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $key => $label): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                <button wire:click="setPreset('<?php echo e($key); ?>')"
                    class="px-3 py-1.5 rounded-lg text-sm font-medium transition-colors
                        <?php echo e($preset === $key
                            ? 'bg-primary-600 text-white'
                            : 'bg-white dark:bg-gray-800 text-gray-700 dark:text-gray-300 border border-gray-300 dark:border-gray-600 hover:bg-gray-50'); ?>">
                    <?php echo e($label); ?>

                </button>
            <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?><?php if(\Livewire\Mechanisms\ExtendBlade\ExtendBlade::isRenderingLivewireComponent()): ?><!--[if ENDBLOCK]><![endif]--><?php endif; ?>
        </div>

        
        <div class="flex items-center gap-2">
            <input type="date" wire:model.live="desde"
                class="rounded-lg border-gray-300 dark:border-gray-600 dark:bg-gray-800 dark:text-white text-sm px-3 py-1.5 focus:ring-primary-500 focus:border-primary-500">
            <span class="text-gray-400 text-sm">—</span>
            <input type="date" wire:model.live="hasta"
                class="rounded-lg border-gray-300 dark:border-gray-600 dark:bg-gray-800 dark:text-white text-sm px-3 py-1.5 focus:ring-primary-500 focus:border-primary-500">
        </div>

        
        <a href="<?php echo e($this->getExportUrl()); ?>" target="_blank"
            class="ml-auto inline-flex items-center gap-1.5 px-4 py-1.5 rounded-lg bg-success-600 hover:bg-success-700 text-white text-sm font-medium transition-colors">
            <?php if (isset($component)) { $__componentOriginal643fe1b47aec0b76658e1a0200b34b2c = $component; } ?>
<?php if (isset($attributes)) { $__attributesOriginal643fe1b47aec0b76658e1a0200b34b2c = $attributes; } ?>
<?php $component = BladeUI\Icons\Components\Svg::resolve([] + (isset($attributes) && $attributes instanceof Illuminate\View\ComponentAttributeBag ? $attributes->all() : [])); ?>
<?php $component->withName('heroicon-o-arrow-down-tray'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php if (isset($attributes) && $attributes instanceof Illuminate\View\ComponentAttributeBag): ?>
<?php $attributes = $attributes->except(\BladeUI\Icons\Components\Svg::ignoredParameterNames()); ?>
<?php endif; ?>
<?php $component->withAttributes(['class' => 'w-4 h-4']); ?>
<?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__attributesOriginal643fe1b47aec0b76658e1a0200b34b2c)): ?>
<?php $attributes = $__attributesOriginal643fe1b47aec0b76658e1a0200b34b2c; ?>
<?php unset($__attributesOriginal643fe1b47aec0b76658e1a0200b34b2c); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal643fe1b47aec0b76658e1a0200b34b2c)): ?>
<?php $component = $__componentOriginal643fe1b47aec0b76658e1a0200b34b2c; ?>
<?php unset($__componentOriginal643fe1b47aec0b76658e1a0200b34b2c); ?>
<?php endif; ?>
            Exportar Excel
        </a>
    </div>

    <?php $data = $this->getReportData(); ?>

    
    <div style="display:grid; grid-template-columns:repeat(4,minmax(0,1fr)); gap:1rem; margin-bottom:1.5rem;">
        <div class="rounded-xl bg-white dark:bg-gray-800 border border-gray-200 dark:border-gray-700 p-4 shadow-sm">
            <p class="text-xs font-semibold text-gray-400 uppercase tracking-wide"># Ventas</p>
            <p class="text-2xl font-bold text-gray-900 dark:text-white mt-1"><?php echo e($data['grandTotal']['count']); ?></p>
            <p class="text-xs text-gray-400 mt-0.5">
                <?php echo e(\Carbon\Carbon::parse($data['desde'])->format('d/m/Y')); ?> —
                <?php echo e(\Carbon\Carbon::parse($data['hasta'])->format('d/m/Y')); ?>

            </p>
        </div>

        <div class="rounded-xl bg-white dark:bg-gray-800 border border-gray-200 dark:border-gray-700 p-4 shadow-sm">
            <p class="text-xs font-semibold text-gray-400 uppercase tracking-wide">Bruto Total</p>
            <?php if(\Livewire\Mechanisms\ExtendBlade\ExtendBlade::isRenderingLivewireComponent()): ?><!--[if BLOCK]><![endif]--><?php endif; ?><?php if($data['grandTotal']['usd']['bruto'] > 0): ?>
                <p class="text-xl font-bold text-gray-900 dark:text-white mt-1">$<?php echo e(number_format($data['grandTotal']['usd']['bruto'], 2)); ?></p>
            <?php endif; ?><?php if(\Livewire\Mechanisms\ExtendBlade\ExtendBlade::isRenderingLivewireComponent()): ?><!--[if ENDBLOCK]><![endif]--><?php endif; ?>
            <?php if(\Livewire\Mechanisms\ExtendBlade\ExtendBlade::isRenderingLivewireComponent()): ?><!--[if BLOCK]><![endif]--><?php endif; ?><?php if($data['grandTotal']['bob']['bruto'] > 0): ?>
                <p class="text-xl font-bold text-amber-600 mt-0.5">Bs. <?php echo e(number_format($data['grandTotal']['bob']['bruto'], 2)); ?></p>
            <?php endif; ?><?php if(\Livewire\Mechanisms\ExtendBlade\ExtendBlade::isRenderingLivewireComponent()): ?><!--[if ENDBLOCK]><![endif]--><?php endif; ?>
            <?php if(\Livewire\Mechanisms\ExtendBlade\ExtendBlade::isRenderingLivewireComponent()): ?><!--[if BLOCK]><![endif]--><?php endif; ?><?php if($data['grandTotal']['usd']['bruto'] == 0 && $data['grandTotal']['bob']['bruto'] == 0): ?>
                <p class="text-xl font-bold text-gray-400 mt-1">—</p>
            <?php endif; ?><?php if(\Livewire\Mechanisms\ExtendBlade\ExtendBlade::isRenderingLivewireComponent()): ?><!--[if ENDBLOCK]><![endif]--><?php endif; ?>
        </div>

        <div class="rounded-xl bg-white dark:bg-gray-800 border border-gray-200 dark:border-gray-700 p-4 shadow-sm">
            <p class="text-xs font-semibold text-gray-400 uppercase tracking-wide">Fee Plataforma</p>
            <?php if(\Livewire\Mechanisms\ExtendBlade\ExtendBlade::isRenderingLivewireComponent()): ?><!--[if BLOCK]><![endif]--><?php endif; ?><?php if($data['grandTotal']['usd']['fee'] > 0): ?>
                <p class="text-xl font-bold text-orange-500 mt-1">−$<?php echo e(number_format($data['grandTotal']['usd']['fee'], 2)); ?></p>
            <?php else: ?>
                <p class="text-xl font-bold text-gray-400 mt-1">—</p>
            <?php endif; ?><?php if(\Livewire\Mechanisms\ExtendBlade\ExtendBlade::isRenderingLivewireComponent()): ?><!--[if ENDBLOCK]><![endif]--><?php endif; ?>
        </div>

        <div class="rounded-xl bg-primary-50 dark:bg-primary-900/30 border border-primary-200 dark:border-primary-700 p-4 shadow-sm">
            <p class="text-xs font-semibold text-primary-500 uppercase tracking-wide">Neto Total (Bs. equiv.)</p>
            <p class="text-2xl font-bold text-primary-600 dark:text-primary-400 mt-1">
                Bs. <?php echo e(number_format($data['grandTotal']['totalBs'], 2)); ?>

            </p>
            <?php if(\Livewire\Mechanisms\ExtendBlade\ExtendBlade::isRenderingLivewireComponent()): ?><!--[if BLOCK]><![endif]--><?php endif; ?><?php if($data['grandTotal']['usd']['neto'] > 0): ?>
                <p class="text-xs text-primary-400 mt-0.5">
                    $<?php echo e(number_format($data['grandTotal']['usd']['neto'], 2)); ?>

                    × <?php echo e(number_format($data['rate'], 2)); ?> = Bs. <?php echo e(number_format($data['grandTotal']['usd']['neto'] * $data['rate'], 2)); ?>

                </p>
            <?php endif; ?><?php if(\Livewire\Mechanisms\ExtendBlade\ExtendBlade::isRenderingLivewireComponent()): ?><!--[if ENDBLOCK]><![endif]--><?php endif; ?>
        </div>
    </div>

    
    <?php if(\Livewire\Mechanisms\ExtendBlade\ExtendBlade::isRenderingLivewireComponent()): ?><!--[if BLOCK]><![endif]--><?php endif; ?><?php $__empty_1 = true; $__currentLoopData = $data['origins']; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $originKey => $group): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); $__empty_1 = false; ?>
        <?php if (isset($component)) { $__componentOriginalee08b1367eba38734199cf7829b1d1e9 = $component; } ?>
<?php if (isset($attributes)) { $__attributesOriginalee08b1367eba38734199cf7829b1d1e9 = $attributes; } ?>
<?php $component = Illuminate\View\AnonymousComponent::resolve(['view' => 'filament::components.section.index','data' => ['class' => 'mb-4','collapsible' => true]] + (isset($attributes) && $attributes instanceof Illuminate\View\ComponentAttributeBag ? $attributes->all() : [])); ?>
<?php $component->withName('filament::section'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php if (isset($attributes) && $attributes instanceof Illuminate\View\ComponentAttributeBag): ?>
<?php $attributes = $attributes->except(\Illuminate\View\AnonymousComponent::ignoredParameterNames()); ?>
<?php endif; ?>
<?php $component->withAttributes(['class' => 'mb-4','collapsible' => true]); ?>
             <?php $__env->slot('heading', null, []); ?> 
                <span class="text-base font-semibold">
                    <?php echo e($group['icon']); ?> <?php echo e($group['label']); ?>

                    <span class="ml-2 text-sm font-normal text-gray-400">(<?php echo e($group['sales']->count()); ?> ventas)</span>
                </span>
             <?php $__env->endSlot(); ?>

            <div class="overflow-x-auto">
                <table class="w-full text-sm">
                    <thead>
                        <tr class="border-b border-gray-200 dark:border-gray-700">
                            <th class="text-left py-2 px-3 text-xs font-semibold text-gray-500 uppercase">Fecha</th>
                            <th class="text-left py-2 px-3 text-xs font-semibold text-gray-500 uppercase">Cliente</th>
                            <th class="text-left py-2 px-3 text-xs font-semibold text-gray-500 uppercase">Venta</th>
                            <th class="text-center py-2 px-3 text-xs font-semibold text-gray-500 uppercase">Mon.</th>
                            <th class="text-right py-2 px-3 text-xs font-semibold text-gray-500 uppercase">Bruto</th>
                            <th class="text-right py-2 px-3 text-xs font-semibold text-gray-500 uppercase">Fee</th>
                            <th class="text-right py-2 px-3 text-xs font-semibold text-gray-500 uppercase">Neto</th>
                            <th class="text-center py-2 px-3 text-xs font-semibold text-gray-500 uppercase">Estado</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if(\Livewire\Mechanisms\ExtendBlade\ExtendBlade::isRenderingLivewireComponent()): ?><!--[if BLOCK]><![endif]--><?php endif; ?><?php $__currentLoopData = $group['sales']; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $sale): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                            <tr class="border-b border-gray-100 dark:border-gray-800 hover:bg-gray-50 dark:hover:bg-gray-800/50">
                                <td class="py-2 px-3 text-gray-500 whitespace-nowrap">
                                    <?php echo e($sale->sale_date?->format('d/m/Y')); ?>

                                </td>
                                <td class="py-2 px-3 font-medium text-gray-900 dark:text-white">
                                    <?php echo e($sale->client?->name); ?>

                                </td>
                                <td class="py-2 px-3 text-gray-600 dark:text-gray-300 max-w-xs truncate" title="<?php echo e($sale->title); ?>">
                                    <?php echo e($sale->title); ?>

                                </td>
                                <td class="py-2 px-3 text-center">
                                    <span class="inline-flex px-1.5 py-0.5 rounded text-xs font-semibold
                                        <?php echo e($sale->currency === \App\Enums\Currency::USD ? 'bg-green-100 text-green-700' : 'bg-amber-100 text-amber-700'); ?>">
                                        <?php echo e($sale->currency?->value); ?>

                                    </span>
                                </td>
                                <td class="py-2 px-3 text-right font-mono text-gray-700 dark:text-gray-300">
                                    <?php echo e($sale->currency?->symbol()); ?><?php echo e(number_format((float)$sale->gross_amount, 2)); ?>

                                </td>
                                <td class="py-2 px-3 text-right font-mono text-orange-500">
                                    <?php echo e($sale->platform_fee > 0 ? '−'.$sale->currency?->symbol().number_format((float)$sale->platform_fee, 2) : '—'); ?>

                                </td>
                                <td class="py-2 px-3 text-right font-mono font-semibold text-gray-900 dark:text-white">
                                    <?php echo e($sale->currency?->symbol()); ?><?php echo e(number_format($sale->net_expected, 2)); ?>

                                </td>
                                <td class="py-2 px-3 text-center">
                                    <?php $status = $sale->payment_status; ?>
                                    <span class="inline-flex px-2 py-0.5 rounded-full text-xs font-medium
                                        <?php echo e($status === \App\Enums\PaymentStatus::Paid    ? 'bg-green-100 text-green-700' : ''); ?>

                                        <?php echo e($status === \App\Enums\PaymentStatus::Partial ? 'bg-yellow-100 text-yellow-700' : ''); ?>

                                        <?php echo e($status === \App\Enums\PaymentStatus::Unpaid  ? 'bg-red-100 text-red-700' : ''); ?>">
                                        <?php echo e($status?->label()); ?>

                                    </span>
                                </td>
                            </tr>
                        <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?><?php if(\Livewire\Mechanisms\ExtendBlade\ExtendBlade::isRenderingLivewireComponent()): ?><!--[if ENDBLOCK]><![endif]--><?php endif; ?>
                    </tbody>
                    
                    <tfoot>
                        <tr class="border-t-2 border-gray-300 dark:border-gray-600 bg-gray-50 dark:bg-gray-800/60 font-semibold">
                            <td colspan="4" class="py-2 px-3 text-right text-gray-600 dark:text-gray-300 text-xs uppercase">
                                Subtotal <?php echo e($group['label']); ?>

                            </td>
                            <td class="py-2 px-3 text-right font-mono text-gray-700 dark:text-gray-200">
                                <?php if(\Livewire\Mechanisms\ExtendBlade\ExtendBlade::isRenderingLivewireComponent()): ?><!--[if BLOCK]><![endif]--><?php endif; ?><?php if($group['totals']['usd']['bruto'] > 0): ?> $<?php echo e(number_format($group['totals']['usd']['bruto'], 2)); ?><?php endif; ?><?php if(\Livewire\Mechanisms\ExtendBlade\ExtendBlade::isRenderingLivewireComponent()): ?><!--[if ENDBLOCK]><![endif]--><?php endif; ?>
                                <?php if(\Livewire\Mechanisms\ExtendBlade\ExtendBlade::isRenderingLivewireComponent()): ?><!--[if BLOCK]><![endif]--><?php endif; ?><?php if($group['totals']['bob']['bruto'] > 0): ?> <br><span class="text-amber-600">Bs. <?php echo e(number_format($group['totals']['bob']['bruto'], 2)); ?></span><?php endif; ?><?php if(\Livewire\Mechanisms\ExtendBlade\ExtendBlade::isRenderingLivewireComponent()): ?><!--[if ENDBLOCK]><![endif]--><?php endif; ?>
                            </td>
                            <td class="py-2 px-3 text-right font-mono text-orange-500">
                                <?php if(\Livewire\Mechanisms\ExtendBlade\ExtendBlade::isRenderingLivewireComponent()): ?><!--[if BLOCK]><![endif]--><?php endif; ?><?php if($group['totals']['usd']['fee'] > 0): ?> −$<?php echo e(number_format($group['totals']['usd']['fee'], 2)); ?><?php endif; ?><?php if(\Livewire\Mechanisms\ExtendBlade\ExtendBlade::isRenderingLivewireComponent()): ?><!--[if ENDBLOCK]><![endif]--><?php endif; ?>
                            </td>
                            <td class="py-2 px-3 text-right font-mono text-primary-600 dark:text-primary-400">
                                <?php if(\Livewire\Mechanisms\ExtendBlade\ExtendBlade::isRenderingLivewireComponent()): ?><!--[if BLOCK]><![endif]--><?php endif; ?><?php if($group['totals']['usd']['neto'] > 0): ?> $<?php echo e(number_format($group['totals']['usd']['neto'], 2)); ?><?php endif; ?><?php if(\Livewire\Mechanisms\ExtendBlade\ExtendBlade::isRenderingLivewireComponent()): ?><!--[if ENDBLOCK]><![endif]--><?php endif; ?>
                                <?php if(\Livewire\Mechanisms\ExtendBlade\ExtendBlade::isRenderingLivewireComponent()): ?><!--[if BLOCK]><![endif]--><?php endif; ?><?php if($group['totals']['bob']['neto'] > 0): ?> <br><span class="text-amber-600">Bs. <?php echo e(number_format($group['totals']['bob']['neto'], 2)); ?></span><?php endif; ?><?php if(\Livewire\Mechanisms\ExtendBlade\ExtendBlade::isRenderingLivewireComponent()): ?><!--[if ENDBLOCK]><![endif]--><?php endif; ?>
                            </td>
                            <td></td>
                        </tr>
                    </tfoot>
                </table>
            </div>
         <?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__attributesOriginalee08b1367eba38734199cf7829b1d1e9)): ?>
<?php $attributes = $__attributesOriginalee08b1367eba38734199cf7829b1d1e9; ?>
<?php unset($__attributesOriginalee08b1367eba38734199cf7829b1d1e9); ?>
<?php endif; ?>
<?php if (isset($__componentOriginalee08b1367eba38734199cf7829b1d1e9)): ?>
<?php $component = $__componentOriginalee08b1367eba38734199cf7829b1d1e9; ?>
<?php unset($__componentOriginalee08b1367eba38734199cf7829b1d1e9); ?>
<?php endif; ?>
    <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); if ($__empty_1): ?>
        <?php if (isset($component)) { $__componentOriginalee08b1367eba38734199cf7829b1d1e9 = $component; } ?>
<?php if (isset($attributes)) { $__attributesOriginalee08b1367eba38734199cf7829b1d1e9 = $attributes; } ?>
<?php $component = Illuminate\View\AnonymousComponent::resolve(['view' => 'filament::components.section.index','data' => []] + (isset($attributes) && $attributes instanceof Illuminate\View\ComponentAttributeBag ? $attributes->all() : [])); ?>
<?php $component->withName('filament::section'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php if (isset($attributes) && $attributes instanceof Illuminate\View\ComponentAttributeBag): ?>
<?php $attributes = $attributes->except(\Illuminate\View\AnonymousComponent::ignoredParameterNames()); ?>
<?php endif; ?>
<?php $component->withAttributes([]); ?>
            <p class="text-center text-gray-400 py-8">No hay ventas en el período seleccionado.</p>
         <?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__attributesOriginalee08b1367eba38734199cf7829b1d1e9)): ?>
<?php $attributes = $__attributesOriginalee08b1367eba38734199cf7829b1d1e9; ?>
<?php unset($__attributesOriginalee08b1367eba38734199cf7829b1d1e9); ?>
<?php endif; ?>
<?php if (isset($__componentOriginalee08b1367eba38734199cf7829b1d1e9)): ?>
<?php $component = $__componentOriginalee08b1367eba38734199cf7829b1d1e9; ?>
<?php unset($__componentOriginalee08b1367eba38734199cf7829b1d1e9); ?>
<?php endif; ?>
    <?php endif; ?><?php if(\Livewire\Mechanisms\ExtendBlade\ExtendBlade::isRenderingLivewireComponent()): ?><!--[if ENDBLOCK]><![endif]--><?php endif; ?>

    
    <?php if(\Livewire\Mechanisms\ExtendBlade\ExtendBlade::isRenderingLivewireComponent()): ?><!--[if BLOCK]><![endif]--><?php endif; ?><?php if($data['grandTotal']['count'] > 0): ?>
        <div class="rounded-xl bg-primary-600 dark:bg-primary-700 p-4 flex flex-wrap items-center justify-between gap-4 mt-2">
            <div class="text-white">
                <p class="text-xs font-semibold uppercase tracking-wide opacity-80">TOTAL NETO DEL PERÍODO</p>
                <p class="text-3xl font-bold mt-0.5">Bs. <?php echo e(number_format($data['grandTotal']['totalBs'], 2)); ?></p>
            </div>
            <div class="flex gap-6 text-white/90 text-sm">
                <?php if(\Livewire\Mechanisms\ExtendBlade\ExtendBlade::isRenderingLivewireComponent()): ?><!--[if BLOCK]><![endif]--><?php endif; ?><?php if($data['grandTotal']['usd']['neto'] > 0): ?>
                    <div>
                        <p class="text-xs opacity-70">USD Neto</p>
                        <p class="font-semibold">$<?php echo e(number_format($data['grandTotal']['usd']['neto'], 2)); ?></p>
                    </div>
                <?php endif; ?><?php if(\Livewire\Mechanisms\ExtendBlade\ExtendBlade::isRenderingLivewireComponent()): ?><!--[if ENDBLOCK]><![endif]--><?php endif; ?>
                <?php if(\Livewire\Mechanisms\ExtendBlade\ExtendBlade::isRenderingLivewireComponent()): ?><!--[if BLOCK]><![endif]--><?php endif; ?><?php if($data['grandTotal']['bob']['neto'] > 0): ?>
                    <div>
                        <p class="text-xs opacity-70">BOB Neto</p>
                        <p class="font-semibold">Bs. <?php echo e(number_format($data['grandTotal']['bob']['neto'], 2)); ?></p>
                    </div>
                <?php endif; ?><?php if(\Livewire\Mechanisms\ExtendBlade\ExtendBlade::isRenderingLivewireComponent()): ?><!--[if ENDBLOCK]><![endif]--><?php endif; ?>
                <?php if(\Livewire\Mechanisms\ExtendBlade\ExtendBlade::isRenderingLivewireComponent()): ?><!--[if BLOCK]><![endif]--><?php endif; ?><?php if($data['grandTotal']['usd']['fee'] > 0): ?>
                    <div>
                        <p class="text-xs opacity-70">Fee Plataforma</p>
                        <p class="font-semibold text-orange-300">−$<?php echo e(number_format($data['grandTotal']['usd']['fee'], 2)); ?></p>
                    </div>
                <?php endif; ?><?php if(\Livewire\Mechanisms\ExtendBlade\ExtendBlade::isRenderingLivewireComponent()): ?><!--[if ENDBLOCK]><![endif]--><?php endif; ?>
            </div>
        </div>
    <?php endif; ?><?php if(\Livewire\Mechanisms\ExtendBlade\ExtendBlade::isRenderingLivewireComponent()): ?><!--[if ENDBLOCK]><![endif]--><?php endif; ?>

 <?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__attributesOriginal166a02a7c5ef5a9331faf66fa665c256)): ?>
<?php $attributes = $__attributesOriginal166a02a7c5ef5a9331faf66fa665c256; ?>
<?php unset($__attributesOriginal166a02a7c5ef5a9331faf66fa665c256); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal166a02a7c5ef5a9331faf66fa665c256)): ?>
<?php $component = $__componentOriginal166a02a7c5ef5a9331faf66fa665c256; ?>
<?php unset($__componentOriginal166a02a7c5ef5a9331faf66fa665c256); ?>
<?php endif; ?>
<?php /**PATH /home/ninatech/ventas.nuna.tech/resources/views/filament/pages/sales-report-page.blade.php ENDPATH**/ ?>