<?php if (isset($component)) { $__componentOriginal166a02a7c5ef5a9331faf66fa665c256 = $component; } ?>
<?php if (isset($attributes)) { $__attributesOriginal166a02a7c5ef5a9331faf66fa665c256 = $attributes; } ?>
<?php $component = Illuminate\View\AnonymousComponent::resolve(['view' => 'filament-panels::components.page.index','data' => []] + (isset($attributes) && $attributes instanceof Illuminate\View\ComponentAttributeBag ? $attributes->all() : [])); ?>
<?php $component->withName('filament-panels::page'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php if (isset($attributes) && $attributes instanceof Illuminate\View\ComponentAttributeBag): ?>
<?php $attributes = $attributes->except(\Illuminate\View\AnonymousComponent::ignoredParameterNames()); ?>
<?php endif; ?>
<?php $component->withAttributes([]); ?>

    
    <div class="flex flex-wrap items-end gap-3 mb-6">

        
        <div class="flex gap-1">
            <?php if(\Livewire\Mechanisms\ExtendBlade\ExtendBlade::isRenderingLivewireComponent()): ?><!--[if BLOCK]><![endif]--><?php endif; ?><?php $__currentLoopData = ['month' => 'Este mes', 'lastmonth' => 'Mes pasado', 'months3' => 'Últ. 3 meses']; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $key => $label): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                <button wire:click="setPreset('<?php echo e($key); ?>')"
                    class="px-3 py-1.5 rounded-lg text-sm font-medium transition-colors
                        <?php echo e($preset === $key
                            ? 'bg-primary-600 text-white'
                            : 'bg-white dark:bg-gray-800 text-gray-700 dark:text-gray-300 border border-gray-300 dark:border-gray-600 hover:bg-gray-50'); ?>">
                    <?php echo e($label); ?>

                </button>
            <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?><?php if(\Livewire\Mechanisms\ExtendBlade\ExtendBlade::isRenderingLivewireComponent()): ?><!--[if ENDBLOCK]><![endif]--><?php endif; ?>
        </div>

        
        <div class="flex items-center gap-2">
            <input type="date" wire:model.live="desde"
                class="rounded-lg border-gray-300 dark:border-gray-600 dark:bg-gray-800 dark:text-white text-sm px-3 py-1.5">
            <span class="text-gray-400 text-sm">—</span>
            <input type="date" wire:model.live="hasta"
                class="rounded-lg border-gray-300 dark:border-gray-600 dark:bg-gray-800 dark:text-white text-sm px-3 py-1.5">
        </div>

        
        <a href="<?php echo e($this->getExportUrl()); ?>" target="_blank"
            class="ml-auto inline-flex items-center gap-1.5 px-4 py-1.5 rounded-lg bg-success-600 hover:bg-success-700 text-white text-sm font-medium transition-colors">
            <?php if (isset($component)) { $__componentOriginal643fe1b47aec0b76658e1a0200b34b2c = $component; } ?>
<?php if (isset($attributes)) { $__attributesOriginal643fe1b47aec0b76658e1a0200b34b2c = $attributes; } ?>
<?php $component = BladeUI\Icons\Components\Svg::resolve([] + (isset($attributes) && $attributes instanceof Illuminate\View\ComponentAttributeBag ? $attributes->all() : [])); ?>
<?php $component->withName('heroicon-o-arrow-down-tray'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php if (isset($attributes) && $attributes instanceof Illuminate\View\ComponentAttributeBag): ?>
<?php $attributes = $attributes->except(\BladeUI\Icons\Components\Svg::ignoredParameterNames()); ?>
<?php endif; ?>
<?php $component->withAttributes(['class' => 'w-4 h-4']); ?>
<?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__attributesOriginal643fe1b47aec0b76658e1a0200b34b2c)): ?>
<?php $attributes = $__attributesOriginal643fe1b47aec0b76658e1a0200b34b2c; ?>
<?php unset($__attributesOriginal643fe1b47aec0b76658e1a0200b34b2c); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal643fe1b47aec0b76658e1a0200b34b2c)): ?>
<?php $component = $__componentOriginal643fe1b47aec0b76658e1a0200b34b2c; ?>
<?php unset($__componentOriginal643fe1b47aec0b76658e1a0200b34b2c); ?>
<?php endif; ?>
            Exportar Excel
        </a>
    </div>

    <?php $data = $this->getReportData(); ?>

    
    <div style="display:grid; grid-template-columns:repeat(4,minmax(0,1fr)); gap:1rem; margin-bottom:1.5rem;">

        <div class="rounded-xl bg-red-50 dark:bg-red-900/20 border border-red-200 dark:border-red-800 p-4 shadow-sm">
            <p class="text-xs font-semibold text-red-400 uppercase tracking-wide">Total Pendiente</p>
            <p class="text-2xl font-bold text-red-600 dark:text-red-400 mt-1">
                Bs. <?php echo e(number_format($data['totalPendingBs'], 2)); ?>

            </p>
            <p class="text-xs text-red-400 mt-0.5"><?php echo e($data['pending']->count()); ?> cuentas abiertas</p>
        </div>

        <div class="rounded-xl bg-orange-50 dark:bg-orange-900/20 border border-orange-200 dark:border-orange-800 p-4 shadow-sm">
            <p class="text-xs font-semibold text-orange-400 uppercase tracking-wide">Total Vencido</p>
            <p class="text-2xl font-bold text-orange-600 dark:text-orange-400 mt-1">
                Bs. <?php echo e(number_format($data['totalOverdueBs'], 2)); ?>

            </p>
            <p class="text-xs text-orange-400 mt-0.5">Pasada la F. Cobro</p>
        </div>

        <div class="rounded-xl bg-green-50 dark:bg-green-900/20 border border-green-200 dark:border-green-800 p-4 shadow-sm">
            <p class="text-xs font-semibold text-green-500 uppercase tracking-wide">Cobrado en período</p>
            <p class="text-2xl font-bold text-green-600 dark:text-green-400 mt-1">
                Bs. <?php echo e(number_format($data['collectedInPeriodBs'], 2)); ?>

            </p>
            <p class="text-xs text-green-400 mt-0.5">
                <?php echo e(\Carbon\Carbon::parse($data['desde'])->format('d/m')); ?> —
                <?php echo e(\Carbon\Carbon::parse($data['hasta'])->format('d/m/Y')); ?>

            </p>
        </div>

        <div class="rounded-xl bg-blue-50 dark:bg-blue-900/20 border border-blue-200 dark:border-blue-800 p-4 shadow-sm">
            <p class="text-xs font-semibold text-blue-400 uppercase tracking-wide">Promedio días cobro</p>
            <p class="text-2xl font-bold text-blue-600 dark:text-blue-400 mt-1">
                <?php echo e($data['avgDays'] ? $data['avgDays'].' días' : '—'); ?>

            </p>
            <p class="text-xs text-blue-400 mt-0.5">Desde creación → cobro</p>
        </div>
    </div>

    
    <div style="display:grid; grid-template-columns:repeat(5,minmax(0,1fr)); gap:0.75rem; margin-bottom:1.5rem;">
        <?php if(\Livewire\Mechanisms\ExtendBlade\ExtendBlade::isRenderingLivewireComponent()): ?><!--[if BLOCK]><![endif]--><?php endif; ?><?php $__currentLoopData = $data['aging']; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $key => $bucket): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
            <div class="rounded-lg border p-3 text-center
                <?php echo e($bucket['color'] === 'success' ? 'border-green-200 bg-green-50 dark:bg-green-900/20' : ''); ?>

                <?php echo e($bucket['color'] === 'warning' ? 'border-yellow-200 bg-yellow-50 dark:bg-yellow-900/20' : ''); ?>

                <?php echo e($bucket['color'] === 'danger'  ? 'border-red-200 bg-red-50 dark:bg-red-900/20' : ''); ?>

                <?php echo e($bucket['color'] === 'gray'    ? 'border-gray-200 bg-gray-50 dark:bg-gray-800' : ''); ?>">
                <p class="text-xs font-semibold
                    <?php echo e($bucket['color'] === 'success' ? 'text-green-600' : ''); ?>

                    <?php echo e($bucket['color'] === 'warning' ? 'text-yellow-600' : ''); ?>

                    <?php echo e($bucket['color'] === 'danger'  ? 'text-red-600' : ''); ?>

                    <?php echo e($bucket['color'] === 'gray'    ? 'text-gray-500' : ''); ?>">
                    <?php echo e($bucket['label']); ?>

                </p>
                <p class="text-xl font-bold mt-1
                    <?php echo e($bucket['color'] === 'success' ? 'text-green-700' : ''); ?>

                    <?php echo e($bucket['color'] === 'warning' ? 'text-yellow-700' : ''); ?>

                    <?php echo e($bucket['color'] === 'danger'  ? 'text-red-700' : ''); ?>

                    <?php echo e($bucket['color'] === 'gray'    ? 'text-gray-600' : ''); ?>">
                    <?php echo e($bucket['count']); ?>

                </p>
                <?php if(\Livewire\Mechanisms\ExtendBlade\ExtendBlade::isRenderingLivewireComponent()): ?><!--[if BLOCK]><![endif]--><?php endif; ?><?php if($bucket['totalBs'] > 0): ?>
                    <p class="text-xs mt-0.5
                        <?php echo e($bucket['color'] === 'success' ? 'text-green-500' : ''); ?>

                        <?php echo e($bucket['color'] === 'warning' ? 'text-yellow-500' : ''); ?>

                        <?php echo e($bucket['color'] === 'danger'  ? 'text-red-500' : ''); ?>

                        <?php echo e($bucket['color'] === 'gray'    ? 'text-gray-400' : ''); ?>">
                        Bs. <?php echo e(number_format($bucket['totalBs'], 2)); ?>

                    </p>
                <?php endif; ?><?php if(\Livewire\Mechanisms\ExtendBlade\ExtendBlade::isRenderingLivewireComponent()): ?><!--[if ENDBLOCK]><![endif]--><?php endif; ?>
            </div>
        <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?><?php if(\Livewire\Mechanisms\ExtendBlade\ExtendBlade::isRenderingLivewireComponent()): ?><!--[if ENDBLOCK]><![endif]--><?php endif; ?>
    </div>

    
    <?php if (isset($component)) { $__componentOriginalee08b1367eba38734199cf7829b1d1e9 = $component; } ?>
<?php if (isset($attributes)) { $__attributesOriginalee08b1367eba38734199cf7829b1d1e9 = $attributes; } ?>
<?php $component = Illuminate\View\AnonymousComponent::resolve(['view' => 'filament::components.section.index','data' => ['class' => 'mb-4']] + (isset($attributes) && $attributes instanceof Illuminate\View\ComponentAttributeBag ? $attributes->all() : [])); ?>
<?php $component->withName('filament::section'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php if (isset($attributes) && $attributes instanceof Illuminate\View\ComponentAttributeBag): ?>
<?php $attributes = $attributes->except(\Illuminate\View\AnonymousComponent::ignoredParameterNames()); ?>
<?php endif; ?>
<?php $component->withAttributes(['class' => 'mb-4']); ?>
         <?php $__env->slot('heading', null, []); ?> 
            <span class="text-base font-semibold text-red-600 dark:text-red-400">
                ⏳ Cuentas pendientes de cobro (<?php echo e($data['pending']->count()); ?>)
            </span>
         <?php $__env->endSlot(); ?>

        <?php if(\Livewire\Mechanisms\ExtendBlade\ExtendBlade::isRenderingLivewireComponent()): ?><!--[if BLOCK]><![endif]--><?php endif; ?><?php if($data['pending']->isEmpty()): ?>
            <p class="text-center text-gray-400 py-8">¡Sin cuentas pendientes! 🎉</p>
        <?php else: ?>
            <div class="overflow-x-auto">
                <table class="w-full text-sm">
                    <thead>
                        <tr class="border-b border-gray-200 dark:border-gray-700">
                            <th class="text-left py-2 px-3 text-xs font-semibold text-gray-500 uppercase">Cliente</th>
                            <th class="text-left py-2 px-3 text-xs font-semibold text-gray-500 uppercase">Venta</th>
                            <th class="text-center py-2 px-3 text-xs font-semibold text-gray-500 uppercase">F.Venta</th>
                            <th class="text-center py-2 px-3 text-xs font-semibold text-gray-500 uppercase">F.Cobro</th>
                            <th class="text-center py-2 px-3 text-xs font-semibold text-gray-500 uppercase">Días</th>
                            <th class="text-center py-2 px-3 text-xs font-semibold text-gray-500 uppercase">Mon.</th>
                            <th class="text-right py-2 px-3 text-xs font-semibold text-gray-500 uppercase">Neto</th>
                            <th class="text-right py-2 px-3 text-xs font-semibold text-gray-500 uppercase">Cobrado</th>
                            <th class="text-right py-2 px-3 text-xs font-semibold text-gray-500 uppercase">Saldo</th>
                            <th class="text-center py-2 px-3 text-xs font-semibold text-gray-500 uppercase">Estado</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if(\Livewire\Mechanisms\ExtendBlade\ExtendBlade::isRenderingLivewireComponent()): ?><!--[if BLOCK]><![endif]--><?php endif; ?><?php $__currentLoopData = $data['pending']; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $sale): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                            <?php
                                $hasDate   = (bool) $sale->expected_collect_date;
                                $isPast    = $hasDate && $sale->expected_collect_date->isPast();
                                $daysOver  = $isPast ? (int) now()->diffInDays($sale->expected_collect_date) : 0;
                                $rowColor  = match(true) {
                                    $daysOver > 60 => 'bg-red-50 dark:bg-red-900/10',
                                    $daysOver > 30 => 'bg-orange-50 dark:bg-orange-900/10',
                                    $daysOver > 0  => 'bg-yellow-50 dark:bg-yellow-900/10',
                                    default        => '',
                                };
                            ?>
                            <tr class="border-b border-gray-100 dark:border-gray-800 hover:bg-gray-50 dark:hover:bg-gray-800/50 <?php echo e($rowColor); ?>">
                                <td class="py-2 px-3 font-medium text-gray-900 dark:text-white"><?php echo e($sale->client?->name); ?></td>
                                <td class="py-2 px-3 text-gray-600 dark:text-gray-300 max-w-xs truncate" title="<?php echo e($sale->title); ?>"><?php echo e($sale->title); ?></td>
                                <td class="py-2 px-3 text-center text-gray-500 whitespace-nowrap"><?php echo e($sale->sale_date?->format('d/m/Y')); ?></td>
                                <td class="py-2 px-3 text-center whitespace-nowrap
                                    <?php echo e($isPast ? 'text-red-600 font-semibold' : 'text-gray-500'); ?>">
                                    <?php echo e($hasDate ? $sale->expected_collect_date->format('d/m/Y') : '—'); ?>

                                </td>
                                <td class="py-2 px-3 text-center">
                                    <?php if(\Livewire\Mechanisms\ExtendBlade\ExtendBlade::isRenderingLivewireComponent()): ?><!--[if BLOCK]><![endif]--><?php endif; ?><?php if($daysOver > 0): ?>
                                        <span class="inline-flex px-1.5 py-0.5 rounded text-xs font-bold
                                            <?php echo e($daysOver > 60 ? 'bg-red-100 text-red-700' : ($daysOver > 30 ? 'bg-orange-100 text-orange-700' : 'bg-yellow-100 text-yellow-700')); ?>">
                                            +<?php echo e($daysOver); ?>d
                                        </span>
                                    <?php elseif($hasDate && !$isPast): ?>
                                        <span class="text-green-500 text-xs">Al día</span>
                                    <?php else: ?>
                                        <span class="text-gray-400 text-xs">—</span>
                                    <?php endif; ?><?php if(\Livewire\Mechanisms\ExtendBlade\ExtendBlade::isRenderingLivewireComponent()): ?><!--[if ENDBLOCK]><![endif]--><?php endif; ?>
                                </td>
                                <td class="py-2 px-3 text-center">
                                    <span class="inline-flex px-1.5 py-0.5 rounded text-xs font-semibold
                                        <?php echo e($sale->currency === \App\Enums\Currency::USD ? 'bg-green-100 text-green-700' : 'bg-amber-100 text-amber-700'); ?>">
                                        <?php echo e($sale->currency?->value); ?>

                                    </span>
                                </td>
                                <td class="py-2 px-3 text-right font-mono text-gray-700 dark:text-gray-300">
                                    <?php echo e($sale->currency?->symbol()); ?><?php echo e(number_format($sale->net_expected, 2)); ?>

                                </td>
                                <td class="py-2 px-3 text-right font-mono text-green-600">
                                    <?php echo e($sale->collected_amount_cached > 0 ? $sale->currency?->symbol().number_format((float)$sale->collected_amount_cached,2) : '—'); ?>

                                </td>
                                <td class="py-2 px-3 text-right font-mono font-bold text-red-600">
                                    <?php echo e($sale->currency?->symbol()); ?><?php echo e(number_format($sale->balance, 2)); ?>

                                </td>
                                <td class="py-2 px-3 text-center">
                                    <?php $st = $sale->payment_status; ?>
                                    <span class="inline-flex px-2 py-0.5 rounded-full text-xs font-medium
                                        <?php echo e($st === \App\Enums\PaymentStatus::Partial ? 'bg-yellow-100 text-yellow-700' : 'bg-red-100 text-red-700'); ?>">
                                        <?php echo e($st?->label()); ?>

                                    </span>
                                </td>
                            </tr>
                        <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?><?php if(\Livewire\Mechanisms\ExtendBlade\ExtendBlade::isRenderingLivewireComponent()): ?><!--[if ENDBLOCK]><![endif]--><?php endif; ?>
                    </tbody>
                    <tfoot>
                        <tr class="border-t-2 border-gray-300 dark:border-gray-600 bg-gray-50 dark:bg-gray-800/60 font-semibold">
                            <td colspan="8" class="py-2 px-3 text-right text-xs uppercase text-gray-500">Total pendiente (Bs. equiv.)</td>
                            <td class="py-2 px-3 text-right font-mono text-red-600 text-base">
                                Bs. <?php echo e(number_format($data['totalPendingBs'], 2)); ?>

                            </td>
                            <td></td>
                        </tr>
                    </tfoot>
                </table>
            </div>
        <?php endif; ?><?php if(\Livewire\Mechanisms\ExtendBlade\ExtendBlade::isRenderingLivewireComponent()): ?><!--[if ENDBLOCK]><![endif]--><?php endif; ?>
     <?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__attributesOriginalee08b1367eba38734199cf7829b1d1e9)): ?>
<?php $attributes = $__attributesOriginalee08b1367eba38734199cf7829b1d1e9; ?>
<?php unset($__attributesOriginalee08b1367eba38734199cf7829b1d1e9); ?>
<?php endif; ?>
<?php if (isset($__componentOriginalee08b1367eba38734199cf7829b1d1e9)): ?>
<?php $component = $__componentOriginalee08b1367eba38734199cf7829b1d1e9; ?>
<?php unset($__componentOriginalee08b1367eba38734199cf7829b1d1e9); ?>
<?php endif; ?>

    
    <?php if (isset($component)) { $__componentOriginalee08b1367eba38734199cf7829b1d1e9 = $component; } ?>
<?php if (isset($attributes)) { $__attributesOriginalee08b1367eba38734199cf7829b1d1e9 = $attributes; } ?>
<?php $component = Illuminate\View\AnonymousComponent::resolve(['view' => 'filament::components.section.index','data' => ['collapsible' => true,'collapsed' => true]] + (isset($attributes) && $attributes instanceof Illuminate\View\ComponentAttributeBag ? $attributes->all() : [])); ?>
<?php $component->withName('filament::section'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php if (isset($attributes) && $attributes instanceof Illuminate\View\ComponentAttributeBag): ?>
<?php $attributes = $attributes->except(\Illuminate\View\AnonymousComponent::ignoredParameterNames()); ?>
<?php endif; ?>
<?php $component->withAttributes(['collapsible' => true,'collapsed' => true]); ?>
         <?php $__env->slot('heading', null, []); ?> 
            <span class="text-base font-semibold text-green-600 dark:text-green-400">
                ✅ Cobradas en el período
                (<?php echo e($data['paidInPeriod']->count()); ?> ventas — Bs. <?php echo e(number_format($data['collectedInPeriodBs'], 2)); ?>)
            </span>
         <?php $__env->endSlot(); ?>

        <?php if(\Livewire\Mechanisms\ExtendBlade\ExtendBlade::isRenderingLivewireComponent()): ?><!--[if BLOCK]><![endif]--><?php endif; ?><?php if($data['paidInPeriod']->isEmpty()): ?>
            <p class="text-center text-gray-400 py-6">No hay ventas cobradas en este período.</p>
        <?php else: ?>
            <div class="overflow-x-auto">
                <table class="w-full text-sm">
                    <thead>
                        <tr class="border-b border-gray-200 dark:border-gray-700">
                            <th class="text-left py-2 px-3 text-xs font-semibold text-gray-500 uppercase">Cliente</th>
                            <th class="text-left py-2 px-3 text-xs font-semibold text-gray-500 uppercase">Venta</th>
                            <th class="text-center py-2 px-3 text-xs font-semibold text-gray-500 uppercase">F.Pago</th>
                            <th class="text-center py-2 px-3 text-xs font-semibold text-gray-500 uppercase">Mon.</th>
                            <th class="text-right py-2 px-3 text-xs font-semibold text-gray-500 uppercase">Bruto</th>
                            <th class="text-right py-2 px-3 text-xs font-semibold text-gray-500 uppercase">Neto cobrado</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if(\Livewire\Mechanisms\ExtendBlade\ExtendBlade::isRenderingLivewireComponent()): ?><!--[if BLOCK]><![endif]--><?php endif; ?><?php $__currentLoopData = $data['paidInPeriod']; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $sale): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                            <?php
                                $lastPayment = $sale->payments->sortByDesc('payment_date')->first();
                            ?>
                            <tr class="border-b border-gray-100 dark:border-gray-800 hover:bg-gray-50 dark:hover:bg-gray-800/50">
                                <td class="py-2 px-3 font-medium text-gray-900 dark:text-white"><?php echo e($sale->client?->name); ?></td>
                                <td class="py-2 px-3 text-gray-600 dark:text-gray-300 max-w-xs truncate"><?php echo e($sale->title); ?></td>
                                <td class="py-2 px-3 text-center text-gray-500"><?php echo e($lastPayment?->payment_date?->format('d/m/Y') ?? '—'); ?></td>
                                <td class="py-2 px-3 text-center">
                                    <span class="inline-flex px-1.5 py-0.5 rounded text-xs font-semibold
                                        <?php echo e($sale->currency === \App\Enums\Currency::USD ? 'bg-green-100 text-green-700' : 'bg-amber-100 text-amber-700'); ?>">
                                        <?php echo e($sale->currency?->value); ?>

                                    </span>
                                </td>
                                <td class="py-2 px-3 text-right font-mono text-gray-500">
                                    <?php echo e($sale->currency?->symbol()); ?><?php echo e(number_format((float)$sale->gross_amount, 2)); ?>

                                </td>
                                <td class="py-2 px-3 text-right font-mono font-semibold text-green-600">
                                    <?php echo e($sale->currency?->symbol()); ?><?php echo e(number_format((float)$sale->collected_amount_cached, 2)); ?>

                                </td>
                            </tr>
                        <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?><?php if(\Livewire\Mechanisms\ExtendBlade\ExtendBlade::isRenderingLivewireComponent()): ?><!--[if ENDBLOCK]><![endif]--><?php endif; ?>
                    </tbody>
                </table>
            </div>
        <?php endif; ?><?php if(\Livewire\Mechanisms\ExtendBlade\ExtendBlade::isRenderingLivewireComponent()): ?><!--[if ENDBLOCK]><![endif]--><?php endif; ?>
     <?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__attributesOriginalee08b1367eba38734199cf7829b1d1e9)): ?>
<?php $attributes = $__attributesOriginalee08b1367eba38734199cf7829b1d1e9; ?>
<?php unset($__attributesOriginalee08b1367eba38734199cf7829b1d1e9); ?>
<?php endif; ?>
<?php if (isset($__componentOriginalee08b1367eba38734199cf7829b1d1e9)): ?>
<?php $component = $__componentOriginalee08b1367eba38734199cf7829b1d1e9; ?>
<?php unset($__componentOriginalee08b1367eba38734199cf7829b1d1e9); ?>
<?php endif; ?>

 <?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__attributesOriginal166a02a7c5ef5a9331faf66fa665c256)): ?>
<?php $attributes = $__attributesOriginal166a02a7c5ef5a9331faf66fa665c256; ?>
<?php unset($__attributesOriginal166a02a7c5ef5a9331faf66fa665c256); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal166a02a7c5ef5a9331faf66fa665c256)): ?>
<?php $component = $__componentOriginal166a02a7c5ef5a9331faf66fa665c256; ?>
<?php unset($__componentOriginal166a02a7c5ef5a9331faf66fa665c256); ?>
<?php endif; ?>
<?php /**PATH /home/ninatech/ventas.nuna.tech/resources/views/filament/pages/cxc-report-page.blade.php ENDPATH**/ ?>